==> more_widgets-2.0.6.tar.gz: lib/widgets/overlays/animated_icon_overlay.dart <==
import 'dart:math';
import 'package:flutter/material.dart';

enum AnimationType {rotate, scale}

class AnimatedValidateOverlay extends StatefulWidget {
  final double width;
  final double height;
  final double iconSize;
  final Color backgroundColor;
  final bool dismissOverlayAutomaticallyAfterAnimation;
  final Duration animationDuration;
  final IconData icon;
  final AnimationType animationType;
  AnimatedValidateOverlay({
    this.width = 100,
    this.height = 100,
    this.backgroundColor = Colors.orange,
    this.iconSize = 80,
    required this.icon,
    this.animationType = AnimationType.rotate,
    this.dismissOverlayAutomaticallyAfterAnimation = true,
    this.animationDuration = const Duration(seconds: 2),
  });

  @override
  State createState() => new AnimatedValidateOverlayState();
}

class AnimatedValidateOverlayState extends State<AnimatedValidateOverlay> with SingleTickerProviderStateMixin {

  late Animation<double> _iconAnimation;
  late AnimationController _iconAnimationController;

  @override
  void initState() {
    super.initState();
    _iconAnimationController = new AnimationController(duration: widget.animationDuration, vsync: this);
    _iconAnimation = new CurvedAnimation(parent: _iconAnimationController, curve: Curves.elasticOut);
    _iconAnimation.addListener(() => this.setState(() {
      if (_iconAnimationController.isCompleted && widget.dismissOverlayAutomaticallyAfterAnimation) {
        Navigator.pop(context);
      }
    }));
    _iconAnimationController.forward();
  }

  @override
  void dispose() {
    _iconAnimationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Center(
        child: Container(
          width: widget.width,
          height: widget.animationType == AnimationType.rotate ? widget.width : widget.height,
          decoration: new BoxDecoration(
            color: widget.backgroundColor,
            shape: BoxShape.circle,
          ),
          child: _buildChild(),
        ),
      ),
    );
  }

  Widget _buildChild() {
    switch (widget.animationType) {
      case AnimationType.rotate:
        return new Transform.rotate(
          angle: _iconAnimation.value * 2 * pi,
          child: new Icon(widget.icon, size: _iconAnimation.value * widget.iconSize,),
        );
      case AnimationType.scale:
        return new Transform.scale(
          scale: _iconAnimation.value,
          child: new Icon(widget.icon, size: _iconAnimation.value * widget.iconSize,),
        );
    }
  }
}

==> more_widgets-2.0.14.tar.gz: lib/widgets/overlays/animated_icon_overlay.dart <==
import 'dart:math';
import 'package:flutter/material.dart';

enum AnimationType {rotate, scale}

class AnimatedIconOverlay extends StatefulWidget {
  final double width;
  final double height;
  final double iconSize;
  final Color backgroundColor;
  final bool dismissOverlayAutomaticallyAfterAnimation;
  final Duration animationDuration;
  final IconData icon;
  final AnimationType animationType;
  AnimatedIconOverlay({
    this.width = 100,
    this.height = 100,
    this.backgroundColor = Colors.orange,
    this.iconSize = 80,
    required this.icon,
    this.animationType = AnimationType.rotate,
    this.dismissOverlayAutomaticallyAfterAnimation = true,
    this.animationDuration = const Duration(seconds: 2),
  });

  @override
  State createState() => new AnimatedIconOverlayState();
}

class AnimatedIconOverlayState extends State<AnimatedIconOverlay> with SingleTickerProviderStateMixin {

  late Animation<double> _iconAnimation;
  late AnimationController _iconAnimationController;

  @override
  void initState() {
    super.initState();
    _iconAnimationController = new AnimationController(duration: widget.animationDuration, vsync: this);
    _iconAnimation = new CurvedAnimation(parent: _iconAnimationController, curve: Curves.elasticOut);
    _iconAnimation.addListener(() => this.setState(() {
      if (_iconAnimationController.isCompleted && widget.dismissOverlayAutomaticallyAfterAnimation) {
        Navigator.pop(context);
      }
    }));
    _iconAnimationController.forward();
  }

  @override
  void dispose() {
    _iconAnimationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Center(
        child: Container(
          width: widget.width,
          height: widget.animationType == AnimationType.rotate ? widget.width : widget.height,
          decoration: new BoxDecoration(
            color: widget.backgroundColor,
            shape: BoxShape.circle,
          ),
          child: _buildChild(),
        ),
      ),
    );
  }

  Widget _buildChild() {
    switch (widget.animationType) {
      case AnimationType.rotate:
        return new Transform.rotate(
          angle: _iconAnimation.value * 2 * pi,
          child: new Icon(widget.icon, size: _iconAnimation.value * widget.iconSize,),
        );
      case AnimationType.scale:
        return new Transform.scale(
          scale: _iconAnimation.value,
          child: new Icon(widget.icon, size: _iconAnimation.value * widget.iconSize,),
        );
    }
  }
}
